title:      Videos
desc:       Docnado Markdown Quick Reference
date:       2018/10/12
version:    1.0.0
template:   document
nav:        Document>Videos
percent:    100
authors:    enq@heinventions.com

Docnado supports the ability to embed a plethora of media types, including videos:

```markdown
![](assets/big_buck_bunny.ogv){: .small}

![](assets/big_buck_bunny.ogv){: .medium}

![](assets/big_buck_bunny.ogv)
```

Supported formats include: `.ogv`, `.ogg`, `webm`, `mp4`, and in some browsers `avi`.
{: .info}

![](assets/big_buck_bunny.ogv){: .small}

![](assets/big_buck_bunny.ogv){: .medium}

![](assets/big_buck_bunny.ogv)

Embedded Youtube videos:

```markdown
![](https://www.youtube.com/embed/Jg48NhtIDV8){: .small}

![](https://www.youtube.com/embed/Jg48NhtIDV8){: .medium}

![](https://www.youtube.com/embed/Jg48NhtIDV8)
```

![](https://www.youtube.com/embed/Jg48NhtIDV8){: .small}

![](https://www.youtube.com/embed/Jg48NhtIDV8){: .medium}

![](https://www.youtube.com/embed/Jg48NhtIDV8)
